@@ -18,6 +18,10 @@ FUNCTION_CALL_REGEX = r'\w+\s*[(]'
 CONDITIONAL_BLOCK_REGEX = re.compile(
     r'if\s*[(]|elif\s*[(]|or\s*[(]*[(]|and\s*[(]|not\s*[(]')
 
+# Matches anything that looks like a variable assignment, ie: foo = [1, 2, 3]
+# Ignores equality comparison, ie: foo == [1, 2, 3]
+ASSIGNMENT_REGEX = re.compile(r'([^=])=([^=]*$)')
+
 
 class ErrorCodes(enum.Enum):
     JS101 = "Multi-line container not broken after opening character"
@@ -39,7 +43,7 @@ class MultilineContainers:
     """Ensure the consistency of multiline dict and list style."""
 
     name = 'flake8_multiline_containers'
-    version = '0.0.11'
+    version = '0.0.14'
 
     tree = attr.ib(default=None)
     filename = attr.ib(default="(none)")
@@ -93,6 +97,13 @@ class MultilineContainers:
 
         line = last_line
 
+        # Only scan the part of the line after assignment
+        # If inside a function call, then it's not a variable assignment
+        if not self.function_depth:
+            matched = ASSIGNMENT_REGEX.search(line)
+            if matched:
+                line = matched.group(2)
+
         # Find strings and make sure they're ignored
         for match in STRING_REGEX.finditer(line):
             i = match.group(0)
